==> v0.6.0-rc1.tar.gz: social/l10n/gl.js <==
OC.L10N.register(
    "social",
    {
    "Social" : "Social",
    "Social notifications" : "Notificacións sociais",
    "Please note that the data from alpha2 can only be migrated manually.\n\t\t\t\t\t\tA detailed documentation to guide you during this process is available using the button below." : "Teña en conta que os datos de alpha2 só se poden migrar manualmente.\n\t\t\t\t\t\tEstá dispoñíbel unha documentación detallada para guialo durante este proceso usando o botón seguinte.",
    "Help" : "Axuda",
    "Follow %s on Social" : "Seguir a %s en Social",
    "🎉 Nextcloud becomes part of the federated social networks!" : "🎉 Nextcloud xa forma parte das redes sociais federadas!",
    ".well-known/webfinger isn't properly set up!" : ".well-known/webfinger non está configurado correctamente!",
    "Social needs the .well-known automatic discovery to be properly set up. If Nextcloud is not installed in the root of the domain, it is often the case that Nextcloud cannot configure this automatically. To use Social, the administrator of this Nextcloud instance needs to manually configure the .well-known redirects:" : "Social precisa que o .coñecido descubrimento automático estea configurado correctamente. Se Nextcloud non está instalado na raíz do dominio, adoita ocorrer que Nextcloud non poida configuralo automaticamente. Para usar Social, o administrador desta instancia de Nextcloud debe configurar manualmente as .redireccións coñecidas:",
    "Open documentation" : "Abrir a documentación",
    "Social app setup" : "Configurar a aplicación Social",
    "ActivityPub requires a fixed URL to make entries unique. Note that this cannot be changed later without resetting the Social app." : "ActivityPub precisa un URL fixo para facer as entradas únicas. Déase conta de que isto non se poderá cambiar posteriormente sen restabelecer a aplicación Social.",
    "ActivityPub URL base" : "URL base de ActivityPub",
    "Finish setup" : "Rematar a configuración",
    "The Social app needs to be set up by the server administrator." : "A aplicación Social precisa ser instalada polo administrador do servidor.",
    "Home" : "Inicio",
    "Direct messages" : "Mensaxes directas",
    "Notifications" : "Notificacións",
    "Profile" : "Perfil",
    "Liked" : "Gustoume",
    "Local timeline" : "Liña temporal local",
    "Global timeline" : "Liña temporal federada",
    "Following" : "Seguindo",
    "In reply to" : "En resposta a",
    "Close reply" : "Pechar a resposta",
    "Add attachment" : "Engadir un anexo",
    "Add emoji" : "Engadir un «emoji»",
    "Uploading..." : "Subindo...",
    "Delete" : "Eliminar",
    "Post" : "Publicar",
    "Post to followers" : "Mensaxe para seguidores",
    "Post to mentioned users" : "Publicar aos usuarios mencionados",
    "Post publicly" : "Mensaxe pública",
    "Post to recipients" : "Mensaxe para mencionadas",
    "Post unlisted" : "Mensaxe sen listar",
    "Unfollow" : "Deixar de seguir",
    "Follow" : "Seguir",
    "posts" : "mensaxes",
    "following" : "seguindo",
    "followers" : "seguidores",
    "Website" : "Sitio web",
    "No results found" : "Non se atoparon resultados",
    "There were no results for your search:" : "Non houbo resultados para a súa busca:",
    "Searching for" : "Buscando",
    "boosted" : "reforzado",
    "{account} liked your post" : "A {account} gustoulle a túa publicación",
    "No posts found" : "Non se atoparon mensaxes",
    "Posts from people you follow will show up here" : "As publicacións da xente que vostede segue amosaranse aquí",
    "No direct messages found" : "Non se atoparon mensaxes directas",
    "Posts directed to you will show up here" : "A mensaxes dirixidas a vostede amosaranse aquí",
    "No local posts found" : "Non se atoparon publicacións locais",
    "Posts from other people on this instance will show up here" : "As publicacións doutras persoas desta instancia amosaranse aquí",
    "No notifications found" : "Non se atoparon notificacións",
    "You have not received any notifications yet" : "Aínda non recibiches ningunha notificación",
    "No global posts found" : "Non hai mensaxes federadas",
    "Posts from federated instances will show up here" : "As publicacións das instancias federadas amosaranse aquí",
    "No liked posts found" : "Non se atoparon mensaxes que me gustaran",
    "You have not tooted yet" : "Aínda non fixeches ningún toot",
    "No posts found for this tag" : "Non se atoparon mensaxes por esta etiqueta",
    "No replies found" : "Non se atoparon respostas",
    "hasn't tooted yet" : "aínda non se participou",
    "Reply" : "Responder",
    "Boost" : "Reforzo",
    "Like" : "Gústame",
    "Undo Like" : "Desfacer o Gústame",
    "Go to Social app" : "Vaia á aplicación Social",
    "Error getting Social notifications" : "Produciuse un erro ao recibir notificacións de Social",
    "No Social notifications!" : "Sen notificacións de Social!",
    "Failed to get Social notifications" : "Produciuse un erro ao recibir as notificacións de Social",
    "{account} is following you" : "{account} está a seguirte",
    "Authorization required" : "Requírese autorización",
    "{appDisplayName} would like permission to access your account. It is a third party application." : "{appDisplayName} quere permiso para acceder á túa conta. É unha aplicación de terceiros.",
    "If you do not trust it, then you should not authorize it." : "Se non confías nel, entón non deberías autorizalo.",
    "Authorize" : "Autorizar",
    "Deny" : "Denegar",
    "Follow on Nextcloud Social" : "Seguir no Nextcloud Social",
    "Hello" : "Ola",
    "Please confirm that you want to follow this account:" : "Confirme que quere seguir esta conta:",
    "You are following this account" : "Vostede está a seguir esta conta",
    "Close" : "Pechar",
    "You are going to follow:" : "Vai seguir a:",
    "name@domain of your federation account" : "nome@dominio da súa conta de federación",
    "Continue" : "Continuar",
    "This step is needed as the user is probably not registered on the same server as you are. We will redirect you to your homeserver to follow this account." : "Este paso é necesario porque probabelmente o usuario non estea rexistrado no mesmo servidor no que está vostede. Redirixímolo ao seu servidor de hospedaxe para seguir esta conta.",
    "User not found" : "Non se atopou o usuario",
    "Sorry, we could not find the account of {userId}" : " Mágoa, non foi posíbel atopar a conta de {userId}",
    "Nextcloud becomes part of the federated social networks!" : "Nextcloud pasa a formar parte das redes sociais federadas!",
    "We automatically created a Social account for you. Your Social ID is the same as your Federated Cloud ID:" : "Creamos de xeito automático unha conta Social para vostede. O seu ID Social é o mesmo que o seu ID de nube federada:",
    "Since you are new to Social, start by following the official Nextcloud account so you don't miss any news" : "Xa que vostede é novo en Social, pode comezar seguindo a conta oficial de Nextcloud así non perderá ningunha nova",
    "Follow Nextcloud on mastodon.xyz" : "Siga a Nextcloud en mastodon.xyz",
    "Public" : "Pública",
    "Unlisted" : "Sen listar",
    "Followers" : "Seguidores",
    "Direct" : "Directa"
},
"nplurals=2; plural=(n != 1);");

==> v0.6.1.tar.gz: social/l10n/gl.js <==
OC.L10N.register(
    "social",
    {
    "Social" : "Social",
    "Social notifications" : "Notificacións sociais",
    "Please note that the data from alpha2 can only be migrated manually.\n\t\t\t\t\t\tA detailed documentation to guide you during this process is available using the button below." : "Teña en conta que os datos de alpha2 só se poden migrar manualmente.\n\t\t\t\t\t\tEstá dispoñíbel unha documentación detallada para guialo durante este proceso usando o botón seguinte.",
    "Help" : "Axuda",
    "Follow %s on Social" : "Seguir a %s en Social",
    "🎉 Nextcloud becomes part of the federated social networks!" : "🎉 Nextcloud xa forma parte das redes sociais federadas!",
    ".well-known/webfinger isn't properly set up!" : ".well-known/webfinger non está configurado correctamente!",
    "Social needs the .well-known automatic discovery to be properly set up. If Nextcloud is not installed in the root of the domain, it is often the case that Nextcloud cannot configure this automatically. To use Social, the administrator of this Nextcloud instance needs to manually configure the .well-known redirects:" : "Social precisa que o .coñecido descubrimento automático estea configurado correctamente. Se Nextcloud non está instalado na raíz do dominio, adoita ocorrer que Nextcloud non poida configuralo automaticamente. Para usar Social, o administrador desta instancia de Nextcloud debe configurar manualmente as .redireccións coñecidas:",
    "Open documentation" : "Abrir a documentación",
    "Social app setup" : "Configurar a aplicación Social",
    "ActivityPub requires a fixed URL to make entries unique. Note that this cannot be changed later without resetting the Social app." : "ActivityPub precisa un URL fixo para facer as entradas únicas. Déase conta de que isto non se poderá cambiar posteriormente sen restabelecer a aplicación Social.",
    "ActivityPub URL base" : "URL base de ActivityPub",
    "Finish setup" : "Rematar a configuración",
    "The Social app needs to be set up by the server administrator." : "A aplicación Social precisa ser instalada polo administrador do servidor.",
    "Home" : "Inicio",
    "Direct messages" : "Mensaxes directas",
    "Notifications" : "Notificacións",
    "Profile" : "Perfil",
    "Liked" : "Gustoume",
    "Local timeline" : "Liña temporal local",
    "Global timeline" : "Liña temporal federada",
    "Following" : "Seguindo",
    "In reply to" : "En resposta a",
    "Close reply" : "Pechar a resposta",
    "Add attachment" : "Engadir un anexo",
    "Add emoji" : "Engadir un «emoji»",
    "Uploading..." : "Enviando…",
    "Delete" : "Eliminar",
    "Post" : "Publicar",
    "Post to followers" : "Mensaxe para seguidores",
    "Post publicly" : "Mensaxe pública",
    "Post to recipients" : "Mensaxe para mencionadas",
    "Post unlisted" : "Mensaxe sen listar",
    "Unfollow" : "Deixar de seguir",
    "Follow" : "Seguir",
    "posts" : "mensaxes",
    "following" : "seguindo",
    "followers" : "seguidores",
    "Website" : "Sitio web",
    "No results found" : "Non se atoparon resultados",
    "There were no results for your search:" : "Non houbo resultados para a súa busca:",
    "Searching for" : "Buscando",
    "boosted" : "reforzado",
    "No posts found" : "Non se atoparon mensaxes",
    "Posts from people you follow will show up here" : "As publicacións da xente que vostede segue amosaranse aquí",
    "No direct messages found" : "Non se atoparon mensaxes directas",
    "Posts directed to you will show up here" : "A mensaxes dirixidas a vostede amosaranse aquí",
    "No local posts found" : "Non se atoparon publicacións locais",
    "Posts from other people on this instance will show up here" : "As publicacións doutras persoas desta instancia amosaranse aquí",
    "No notifications found" : "Non se atoparon notificacións",
    "You have not received any notifications yet" : "Aínda non recibiches ningunha notificación",
    "No global posts found" : "Non hai mensaxes federadas",
    "Posts from federated instances will show up here" : "As publicacións das instancias federadas amosaranse aquí",
    "No liked posts found" : "Non se atoparon mensaxes que me gustaran",
    "You have not tooted yet" : "Aínda non fixeches ningún toot",
    "No posts found for this tag" : "Non se atoparon mensaxes por esta etiqueta",
    "No replies found" : "Non se atoparon respostas",
    "hasn't tooted yet" : "aínda non se participou",
    "Reply" : "Responder",
    "Boost" : "Reforzo",
    "Like" : "Gústame",
    "Undo Like" : "Desfacer o Gústame",
    "Go to Social app" : "Vaia á aplicación Social",
    "Error getting Social notifications" : "Produciuse un erro ao recibir notificacións de Social",
    "No Social notifications!" : "Sen notificacións de Social!",
    "Failed to get Social notifications" : "Produciuse un erro ao recibir as notificacións de Social",
    "Authorization required" : "Requírese autorización",
    "{appDisplayName} would like permission to access your account. It is a third party application." : "{appDisplayName} quere permiso para acceder á túa conta. É unha aplicación de terceiros.",
    "If you do not trust it, then you should not authorize it." : "Se non confías nel, entón non deberías autorizalo.",
    "Authorize" : "Autorizar",
    "Deny" : "Denegar",
    "Follow on Nextcloud Social" : "Seguir en Nextcloud Social",
    "Hello" : "Ola",
    "Please confirm that you want to follow this account:" : "Confirme que quere seguir esta conta:",
    "You are following this account" : "Vostede está a seguir esta conta",
    "Close" : "Pechar",
    "You are going to follow:" : "Vai seguir a:",
    "name@domain of your federation account" : "nome@dominio da súa conta de federación",
    "Continue" : "Continuar",
    "This step is needed as the user is probably not registered on the same server as you are. We will redirect you to your homeserver to follow this account." : "Este paso é necesario porque probabelmente o usuario non estea rexistrado no mesmo servidor no que está vostede. Redirixímolo ao seu servidor de hospedaxe para seguir esta conta.",
    "User not found" : "Non se atopou o usuario",
    "Sorry, we could not find the account of {userId}" : " Desculpe, non foi posíbel atopar a conta de {userId}",
    "Nextcloud becomes part of the federated social networks!" : "Nextcloud pasa a formar parte das redes sociais federadas!",
    "We automatically created a Social account for you. Your Social ID is the same as your Federated Cloud ID:" : "Creamos de xeito automático unha conta Social para vostede. O seu ID Social é o mesmo que o seu ID de nube federada:",
    "Since you are new to Social, start by following the official Nextcloud account so you don't miss any news" : "Xa que vostede é novo en Social, pode comezar seguindo a conta oficial de Nextcloud así non perderá ningunha nova",
    "Follow Nextcloud on mastodon.xyz" : "Siga a Nextcloud en mastodon.xyz",
    "Public" : "Pública",
    "Unlisted" : "Sen listar",
    "Followers" : "Seguidores"
},
"nplurals=2; plural=(n != 1);");
